summaryrefslogtreecommitdiffhomepage
path: root/test
diff options
context:
space:
mode:
Diffstat (limited to 'test')
-rw-r--r--test/test-manager/src/tests/daita.rs20
1 files changed, 10 insertions, 10 deletions
diff --git a/test/test-manager/src/tests/daita.rs b/test/test-manager/src/tests/daita.rs
index 912c811ecc..24f5f4b0df 100644
--- a/test/test-manager/src/tests/daita.rs
+++ b/test/test-manager/src/tests/daita.rs
@@ -12,10 +12,10 @@ use test_rpc::ServiceClient;
use super::{helpers, Error, TestContext};
/// Test that daita and daita_smart_routing works by connecting
/// - to a non-DAITA relay with singlehop (should block)
/// - to a DAITA relay with singlehop
/// - to a DAITA relay with auto-multihop using smart_routing
/// - to a DAITA relay with explicit multihop
/// - to a non-DAITA relay with multihop (should block)
///
@@ -90,25 +90,25 @@ pub async fn test_daita(
.await?
.inspect(|event| log::debug!("New daemon event: {event:?}"));
- log::info!("Connecting to non-daita relay with DAITA smart routing");
+ log::info!("Connecting to non-daita relay with DAITA by automatically using multihop");
{
helpers::set_relay_settings(&mut mullvad_client, non_daita_location_query.clone()).await?;
mullvad_client.set_enable_daita(true).await?;
mullvad_client.connect_tunnel().await?;
let state = wait_for_daemon_reconnect(&mut events)
.await
- .context("Failed to connect with smart_routing enabled")?;
+ .context("Failed to connect with 'direct only' disabled")?;
let endpoint: &TunnelEndpoint = state.endpoint().ok_or(anyhow!("No endpoint"))?;
ensure!(endpoint.daita, "DAITA must be used");
ensure!(endpoint.entry_endpoint.is_some(), "multihop must be used");
- log::info!("Successfully multihopped with use smart_routing");
+ log::info!("Successfully multihopped with 'direct only' disabled");
}
- log::info!("Connecting to non-daita relay with DAITA but no smart routing");
+ log::info!("Connecting to non-daita relay with 'DAITA: direct only'");
{
- mullvad_client.set_daita_smart_routing(false).await?;
+ mullvad_client.set_daita_direct_only(true).await?;
let result = wait_for_daemon_reconnect(&mut events).await;
let Err(Error::UnexpectedErrorState(state)) = result else {
@@ -121,13 +121,13 @@ pub async fn test_daita(
log::info!("Failed to connect, this is expected!");
}
- log::info!("Connecting to daita relay with smart_routing");
+ log::info!("Connecting to daita relay with 'direct_only' disabled");
{
helpers::set_relay_settings(&mut mullvad_client, daita_location_query).await?;
let state = wait_for_daemon_reconnect(&mut events)
.await
- .context("Failed to connect to daita location with smart_routing enabled")?;
+ .context("Failed to connect to daita location with 'direct_only' disabled")?;
let endpoint = state.endpoint().context("No endpoint")?;
ensure!(endpoint.daita, "DAITA must be used");
@@ -136,7 +136,7 @@ pub async fn test_daita(
"multihop must not be used"
);
- log::info!("Successfully singlehopped with smart_routing");
+ log::info!("Successfully singlehopped with 'direct_only' disabled");
}
log::info!("Connecting to daita relay with multihop");
@@ -12,10 +12,10 @@ use test_rpc::ServiceClient;
use super::{helpers, Error, TestContext};
-/// Test that daita and daita_smart_routing works by connecting
+/// Test that daita and daita_direct_only works by connecting
/// - to a non-DAITA relay with singlehop (should block)
/// - to a DAITA relay with singlehop
@@ -12,10 +12,10 @@ use test_rpc::ServiceClient;
/// - to a non-DAITA relay with singlehop (should block)
/// - to a DAITA relay with singlehop
-/// - to a DAITA relay with auto-multihop using smart_routing
+/// - to a DAITA relay with auto-multihop by disabling direct_only
/// - to a DAITA relay with explicit multihop
/// - to a non-DAITA relay with multihop (should block)